@@ -3,7 +3,7 @@ set -ex
 source shared-ci/prepare-archlinux.sh
 
 # See *depends in https://github.com/archlinuxcn/repo/blob/master/archlinuxcn/qtermwidget-git/PKGBUILD
-pacman -S --noconfirm --needed git cmake lxqt-build-tools-git qt5-tools python-pyqt5 pyqt-builder sip
+pacman -S --noconfirm --needed git cmake lxqt-build-tools qt6-tools python-pyqt6 pyqt-builder sip
 
 cmake -B build -S . \
     -DBUILD_EXAMPLE=ON \
@@ -11,4 +11,4 @@ cmake -B build -S . \
 make -C build
 
 cd pyqt
-CXXFLAGS="-I$PWD/../lib -I$PWD/../build/lib" LDFLAGS="-L$PWD/../build" sip-wheel --verbose
+CXXFLAGS="-I$PWD/../lib -I$PWD/../build/lib" LDFLAGS="-L$PWD/../build" sip-wheel --verbose --qmake=/usr/bin/qmake6
