@@ -668,6 +668,11 @@ void Screen::checkSelection(int from, int to)
         clearSelection();
 }
 
+static inline bool isRegionalIndicator(wchar_t c)
+{
+    return (c >= 0x1F1E6 && c <= 0x1F1FF); // for creating flag codes
+}
+
 void Screen::displayCharacter(wchar_t c)
 {
     // Note that VT100 does wrapping BEFORE putting the character.
@@ -677,10 +682,12 @@ void Screen::displayCharacter(wchar_t c)
 
     int w = konsole_wcwidth(c);
     if (w < 0)
-        return;
-    if (w == 0)
+        return; // Non-printable character
+    if (w == 0
+        // Also, make an extended character with a pair of flag codes
+        || (w == 1 && isRegionalIndicator(c)))
     {
-        if (QChar(c).category() != QChar::Mark_NonSpacing)
+        if (w == 0 && QChar(c).category() != QChar::Mark_NonSpacing)
             return;
         // Find previous "real character" to try to combine with
         int charToCombineWithX = qMin(cuX, screenLines[cuY].length());
@@ -709,20 +716,69 @@ void Screen::displayCharacter(wchar_t c)
                 previousChar = false;
                 break;
             }
-        } while (screenLines[charToCombineWithY][charToCombineWithX] == 0);
+        } while (w == 0 && screenLines[charToCombineWithY][charToCombineWithX] == 0);
 
         if (!previousChar)
         {
-            w = 2;
+            if (w == 0)
+            {
+                w = 2;
+            }
             goto notcombine;
         }
 
         Character& currentChar = screenLines[charToCombineWithY][charToCombineWithX];
+
+        if (w > 0 && !isRegionalIndicator(currentChar.character))
+        {
+            goto notcombine; // a single regional indicator (useless)
+        }
+
         if ((currentChar.rendition & RE_EXTENDED_CHAR) == 0)
         {
             uint chars[2] = { static_cast<uint>(currentChar.character), static_cast<uint>(c) };
             currentChar.rendition |= RE_EXTENDED_CHAR;
             currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars, 2);
+
+            // when there is a pair of flag codes
+            if (w > 0)
+            {
+                if (cuX + 1 > columns)
+                {
+                    if (getMode(MODE_Wrap))
+                    {
+                        lineProperties[cuY] = (LineProperty)(lineProperties[cuY] | LINE_WRAPPED);
+                        nextLine();
+                    }
+                    else
+                    {
+                        cuX = columns - 1;
+                    }
+                }
+
+                if (screenLines[cuY].size() < cuX + 1)
+                {
+                    screenLines[cuY].resize(cuX + 1);
+                }
+
+                // NOTE: This is needed for correct selection.
+                Character& ch = screenLines[cuY][cuX];
+                ch.character = 0;
+                ch.foregroundColor = effectiveForeground;
+                ch.backgroundColor = effectiveBackground;
+                ch.rendition = effectiveRendition;
+
+                if (getMode(MODE_Insert))
+                {
+                    insertChars(1);
+                }
+
+                lastPos = loc(cuX,cuY);
+                checkSelection(lastPos, lastPos);
+                lastDrawnChar = currentChar.character;
+
+                cuX++;
+            }
         }
         else
         {
