@@ -24,7 +24,7 @@
 // Qt
 #include <QColor>
 #include <QPointer>
-#include <QWidget>
+#include <QScrollBar>
 
 // Konsole
 #include "Filter.h"
@@ -41,7 +41,6 @@ class QTimer;
 class QEvent;
 class QGridLayout;
 class QKeyEvent;
-class QScrollBar;
 class QShowEvent;
 class QHideEvent;
 class QTimerEvent;
@@ -73,6 +72,7 @@ namespace Konsole
 extern unsigned short vt100_graphics[32];
 
 class ScreenWindow;
+class ScrollBar;
 
 /**
  * A widget which displays output from a terminal emulation and sends input keypresses and mouse activity
@@ -433,6 +433,14 @@ public:
     void disableBracketedPasteMode(bool disable) { _disabledBracketedPasteMode = disable; }
     bool bracketedPasteModeIsDisabled() const { return _disabledBracketedPasteMode; }
 
+    int mouseAutohideDelay() const { return _mouseAutohideDelay; }
+
+    /**
+    * hide the mouse cursor after @param delay milliseconds of inactivity
+    * @param delay < 0 deactivates the behavior
+    */
+    void autoHideMouseAfter(int delay);
+
 public slots:
 
     /**
@@ -588,6 +596,8 @@ protected:
     virtual void fontChange(const QFont &font);
     void focusInEvent(QFocusEvent* event) override;
     void focusOutEvent(QFocusEvent* event) override;
+    void enterEvent(QEnterEvent* event) override;
+    void leaveEvent(QEvent* event) override;
     void keyPressEvent(QKeyEvent* event) override;
     void mouseDoubleClickEvent(QMouseEvent* ev) override;
     void mousePressEvent( QMouseEvent* ) override;
@@ -616,7 +626,7 @@ protected:
     //     - A space (returns ' ')
     //     - Part of a word (returns 'a')
     //     - Other characters (returns the input character)
-    QChar charClass(QChar ch) const;
+    QChar charClass(const Character &ch) const;
 
     void clearImage();
 
@@ -657,7 +667,7 @@ private:
     // draws a section of text, all the text in this section
     // has a common color and style
     void drawTextFragment(QPainter& painter, const QRect& rect,
-                          const std::wstring& text, const Character* style);
+                          const std::wstring& text, const Character* style, bool tooWide);
     // draws the background for a text fragment
     // if useOpacitySetting is true then the color's alpha value will be set to
     // the display's transparency (set with setOpacity()), otherwise the background
@@ -669,7 +679,8 @@ private:
                                        const QColor& backgroundColor , bool& invertColors);
     // draws the characters or line graphics in a text fragment
     void drawCharacters(QPainter& painter, const QRect& rect,  const std::wstring& text,
-                                           const Character* style, bool invertCharacterColor);
+                                           const Character* style, bool invertCharacterColor,
+                                           bool tooWide = false);
     // draws a string of line graphics
     void drawLineCharString(QPainter& painter, int x, int y,
                             const std::wstring& str, const Character* attributes) const;
@@ -721,9 +732,11 @@ private:
 
     bool handleShortcutOverrideEvent(QKeyEvent* event);
 
-    bool isLineChar(wchar_t c) const;
+    bool isLineChar(Character c) const;
     bool isLineCharString(const std::wstring& string) const;
 
+    void hideStaleMouse() const; // conditionally hides the mouse cursor
+
     // the window onto the terminal screen which this display
     // is currently showing.
     QPointer<ScreenWindow> _screenWindow;
@@ -733,6 +746,7 @@ private:
     QGridLayout* _gridLayout;
 
     bool _fixedFont; // has fixed pitch
+    bool _fixedFont_original; // used only in textWidth()
     int  _fontHeight;     // height
     int  _fontWidth;     // width
     int  _fontAscent;     // ascend
@@ -783,7 +797,7 @@ private:
     bool    _columnSelectionMode;
 
     QClipboard*  _clipboard;
-    QScrollBar* _scrollBar;
+    ScrollBar* _scrollBar;
     QTermWidget::ScrollBarPosition _scrollbarLocation;
     QString     _wordCharacters;
     int         _bellMode;
@@ -798,6 +812,7 @@ private:
     bool _isFixedSize; //Columns / lines are locked.
     QTimer* _blinkTimer;  // active when hasBlinker
     QTimer* _blinkCursorTimer;  // active when hasBlinkingCursor
+    static std::shared_ptr<QTimer> _hideMouseTimer;
 
     //QMenu* _drop;
     QString _dropText;
@@ -860,6 +875,8 @@ private:
 
     bool _drawLineChars;
 
+    int _mouseAutohideDelay;
+
 public:
     static void setTransparencyEnabled(bool enable)
     {
@@ -881,6 +898,16 @@ private:
     int _timerId;
 };
 
+class ScrollBar : public QScrollBar
+{
+Q_OBJECT
+
+public:
+    ScrollBar(QWidget* parent = nullptr);
+protected:
+    void enterEvent(QEnterEvent* event) override;
+};
+
 }
 
 #endif // TERMINALDISPLAY_H
